@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-Created on Fri Apr  3 19:46:36 2020
+Created on June 2022
 @author: hansb
 """
 
-__version__ = "0.0.32"
+__version__ = "0.1.00"
 
 from .util import *
 from .logger import Logger
